@@ -1,12 +1,12 @@
 # flake8: noqa
 __author__ = "Akio Taniguchi"
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 
 
 # submodules
 from . import apps
+from . import arxiv
 from . import article
 from . import cli
-from . import constants
-from . import search
-from . import translate
+from . import consts
+from . import deepl
