@@ -1,3 +1,6 @@
+__all__ = []
+
+
 # standard library
 from logging import DEBUG, basicConfig, getLogger
 from typing import Sequence
@@ -9,18 +12,20 @@ from fire import Fire
 
 # submodules
 from .apps import slack
-from .constants import (
+from .arxiv import search
+from .consts import (
     CATEGORIES,
     KEYWORDS,
     START_DATE,
     END_DATE,
-    LANGUAGE_FROM,
-    LANGUAGE_TO,
+    SOURCE_LANG,
+    TARGET_LANG,
+    DEEPL_MODE,
     N_CONCURRENT,
     TIMEOUT,
+    DeepLMode,
 )
-from .search import search
-from .translate import translate
+from .deepl import translate
 
 
 # logger
@@ -44,11 +49,13 @@ def cmd_slack(
     keywords: Sequence[str] = KEYWORDS,
     start_date: str = START_DATE,
     end_date: str = END_DATE,
-    language_from: str = LANGUAGE_FROM,
-    language_to: str = LANGUAGE_TO,
+    source_lang: str = SOURCE_LANG,
+    target_lang: str = TARGET_LANG,
+    deepl_mode: DeepLMode = DEEPL_MODE,
+    deepl_api_key: str = "",
     n_concurrent: int = N_CONCURRENT,
     timeout: float = TIMEOUT,
-    webhook_url: str = "",
+    slack_webhook_url: str = "",
     dry_run: bool = False,
     debug: bool = False,
 ) -> None:
@@ -59,11 +66,13 @@ def cmd_slack(
         keywords: Comma-separated keywords for a search.
         start_date: Start date for a search (inclusive).
         end_date: End date for a search (exclusive).
-        language_from: Language of original text in articles.
-        language_to: Language for translated text in articles.
-        n_concurrent: Number of simultaneous execution.
-        timeout: Timeout for each post execution (in seconds).
-        webhook_url: URL of Slack incoming webhook.
+        source_lang: Language of original text in articles.
+        target_lang: Language of translated text in articles.
+        deepl_mode: Translation mode (auto, api, browser) of DeepL.
+        deepl_api_key: Authentication Key for DeepL API (api-mode only).
+        n_concurrent: Number of concurrent translation (browser-mode only).
+        timeout: Timeout for translation in seconds (browser-mode only).
+        slack_webhook_url: URL of Slack incoming webhook.
         dry_run: If True, articles are not posted to Slack.
         debug: If True, debug-level log messages are shown.
 
@@ -89,14 +98,16 @@ def cmd_slack(
         end_date=end_date,
     )
     translated = translate(
-        articles,
-        language_from=language_from,
-        language_to=language_to,
+        list(articles),
+        source_lang=source_lang,
+        target_lang=target_lang,
+        deepl_mode=deepl_mode,
+        deepl_api_key=deepl_api_key,
         n_concurrent=n_concurrent,
         timeout=timeout,
     )
 
-    return slack.post(translated, webhook_url, dry_run)
+    return slack.post(translated, slack_webhook_url, dry_run)
 
 
 def main() -> None:
